@@ -786,5 +786,4 @@ def spiega_modello(reg, df, lista_colonne_x, colonna_y):
     shap_values = explainer.shap_values(X)
     shap.summary_plot(shap_values, X)
     shap.summary_plot(shap_values, X, plot_type='bar')
-    #waterfall plot
-    shap.waterfall_plot(explainer.expected_value, shap_values, X)
+
